@@ -1,14 +1,13 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2020 Arnaud Rebillout
+ * Copyright (C) 2015-2021 Arnaud Rebillout
  *
- * SPDX-License-Identifier: GPL-3.0-or-later
+ * SPDX-License-Identifier: GPL-3.0-only
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * the Free Software Foundation, version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,22 +15,22 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ * along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
-#include <math.h>
-#include <glib.h>
-#include <glib-object.h>
 #include <gio/gio.h>
+#include <glib-object.h>
+#include <glib.h>
+#include <math.h>
 
 #include "base/glib-object-additions.h"
 #include "base/gv-base.h"
-#include "core/gv-engine.h"
 #include "core/gv-core-enum-types.h"
 #include "core/gv-core-internal.h"
+#include "core/gv-engine.h"
 #include "core/gv-metadata.h"
-#include "core/gv-station.h"
 #include "core/gv-station-list.h"
+#include "core/gv-station.h"
 #include "core/gv-streaminfo.h"
 
 #include "core/gv-player.h"
@@ -40,10 +39,10 @@
  * Properties
  */
 
-#define DEFAULT_VOLUME   100
-#define DEFAULT_MUTE     FALSE
-#define DEFAULT_REPEAT   FALSE
-#define DEFAULT_SHUFFLE  FALSE
+#define DEFAULT_VOLUME	 100
+#define DEFAULT_MUTE	 FALSE
+#define DEFAULT_REPEAT	 FALSE
+#define DEFAULT_SHUFFLE	 FALSE
 #define DEFAULT_AUTOPLAY FALSE
 
 enum {
@@ -60,7 +59,7 @@ enum {
 	PROP_PIPELINE_ENABLED,
 	PROP_PIPELINE_STRING,
 	/* Properties */
-	PROP_STATE,
+	PROP_PLAYBACK_STATE,
 	PROP_REPEAT,
 	PROP_SHUFFLE,
 	PROP_AUTOPLAY,
@@ -74,6 +73,18 @@ enum {
 
 static GParamSpec *properties[PROP_N];
 
+/*
+ * Signals
+ */
+
+enum {
+	SIGNAL_SSL_FAILURE,
+	/* Number of signals */
+	SIGNAL_N
+};
+
+static guint signals[SIGNAL_N];
+
 /*
  * GObject definitions
  */
@@ -85,24 +96,24 @@ typedef enum {
 
 struct _GvPlayerPrivate {
 	/* Construct-only properties */
-	GvEngine      *engine;
+	GvEngine *engine;
 	GvStationList *station_list;
 	/* Properties */
-	GvPlayerState  state;
-	gboolean       repeat;
-	gboolean       shuffle;
-	gboolean       autoplay;
+	GvPlaybackState state;
+	gboolean repeat;
+	gboolean shuffle;
+	gboolean autoplay;
 	/* Current station */
-	GvStation     *station;
+	GvStation *station;
 	/* Wished state */
-	GvPlayerWish   wish;
+	GvPlayerWish wish;
 };
 
 typedef struct _GvPlayerPrivate GvPlayerPrivate;
 
 struct _GvPlayer {
 	/* Parent instance structure */
-	GObject          parent_instance;
+	GObject parent_instance;
 	/* Private data */
 	GvPlayerPrivate *priv;
 };
@@ -110,21 +121,49 @@ struct _GvPlayer {
 static void gv_player_configurable_interface_init(GvConfigurableInterface *iface);
 
 G_DEFINE_TYPE_WITH_CODE(GvPlayer, gv_player, G_TYPE_OBJECT,
-                        G_ADD_PRIVATE(GvPlayer)
-                        G_IMPLEMENT_INTERFACE(GV_TYPE_CONFIGURABLE,
-                                        gv_player_configurable_interface_init)
-                        G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
+			G_ADD_PRIVATE(GvPlayer)
+			G_IMPLEMENT_INTERFACE(GV_TYPE_CONFIGURABLE,
+					      gv_player_configurable_interface_init)
+			G_IMPLEMENT_INTERFACE(GV_TYPE_ERRORABLE, NULL))
+
+/*
+ * Playback
+ */
+
+const gchar *
+gv_playback_state_to_string(GvPlaybackState state)
+{
+	const gchar *str;
+
+	switch (state) {
+	case GV_PLAYBACK_STATE_PLAYING:
+		str = _("Playing");
+		break;
+	case GV_PLAYBACK_STATE_CONNECTING:
+		str = _("Connecting…");
+		break;
+	case GV_PLAYBACK_STATE_BUFFERING:
+		str = _("Buffering…");
+		break;
+	case GV_PLAYBACK_STATE_STOPPED:
+	default:
+		str = _("Stopped");
+		break;
+	}
+
+	return str;
+}
 
 /*
  * Signal handlers
  */
 
-static void gv_player_set_state(GvPlayer *self, GvPlayerState value);
+static void gv_player_set_playback_state(GvPlayer *self, GvPlaybackState value);
 
 static void
 on_station_notify(GvStation *station,
-                  GParamSpec *pspec,
-                  GvPlayer  *self)
+		  GParamSpec *pspec,
+		  GvPlayer *self)
 {
 	GvPlayerPrivate *priv = self->priv;
 	const gchar *property_name = g_param_spec_get_name(pspec);
@@ -147,9 +186,9 @@ on_station_notify(GvStation *station,
 }
 
 static void
-on_engine_notify(GvEngine  *engine,
-                 GParamSpec *pspec,
-                 GvPlayer  *self)
+on_engine_notify(GvEngine *engine,
+		 GParamSpec *pspec,
+		 GvPlayer *self)
 {
 	GvPlayerPrivate *priv = self->priv;
 	const gchar *property_name = g_param_spec_get_name(pspec);
@@ -174,25 +213,25 @@ on_engine_notify(GvEngine  *engine,
 	} else if (!g_strcmp0(property_name, "pipeline-string")) {
 		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_PIPELINE_STRING]);
 
-	} else if (!g_strcmp0(property_name, "state")) {
+	} else if (!g_strcmp0(property_name, "playback-state")) {
 		GvEngineState engine_state;
-		GvPlayerState player_state;
+		GvPlaybackState playback_state;
 
 		engine_state = gv_engine_get_state(priv->engine);
 
 		/* Map engine state to player state - trivial */
 		switch (engine_state) {
 		case GV_ENGINE_STATE_STOPPED:
-			player_state = GV_PLAYER_STATE_STOPPED;
+			playback_state = GV_PLAYBACK_STATE_STOPPED;
 			break;
 		case GV_ENGINE_STATE_CONNECTING:
-			player_state = GV_PLAYER_STATE_CONNECTING;
+			playback_state = GV_PLAYBACK_STATE_CONNECTING;
 			break;
 		case GV_ENGINE_STATE_BUFFERING:
-			player_state = GV_PLAYER_STATE_BUFFERING;
+			playback_state = GV_PLAYBACK_STATE_BUFFERING;
 			break;
 		case GV_ENGINE_STATE_PLAYING:
-			player_state = GV_PLAYER_STATE_PLAYING;
+			playback_state = GV_PLAYBACK_STATE_PLAYING;
 			break;
 		default:
 			ERROR("Unhandled engine state: %d", engine_state);
@@ -201,19 +240,29 @@ on_engine_notify(GvEngine  *engine,
 		}
 
 		/* Set state */
-		gv_player_set_state(self, player_state);
+		gv_player_set_playback_state(self, playback_state);
 	}
 }
 
 static void
 on_engine_error(GvEngine *engine G_GNUC_UNUSED,
-                const gchar *error_string G_GNUC_UNUSED,
-                GvPlayer *self)
+		const gchar *error_string G_GNUC_UNUSED,
+		GvPlayer *self)
 {
 	/* Whatever the error, just stop */
 	gv_player_stop(self);
 }
 
+static void
+on_engine_ssl_failure(GvEngine *engine G_GNUC_UNUSED,
+		      const gchar *error,
+		      const gchar *debug,
+		      GvPlayer *self)
+{
+	/* Just forward the signal ... */
+	g_signal_emit(self, signals[SIGNAL_SSL_FAILURE], 0, error, debug);
+}
+
 /*
  * Property accessors - construct-only properties
  */
@@ -231,6 +280,7 @@ gv_player_set_engine(GvPlayer *self, GvEngine *engine)
 	/* Some signal handlers */
 	g_signal_connect_object(engine, "notify", G_CALLBACK(on_engine_notify), self, 0);
 	g_signal_connect_object(engine, "error", G_CALLBACK(on_engine_error), self, 0);
+	g_signal_connect_object(engine, "ssl-failure", G_CALLBACK(on_engine_ssl_failure), self, 0);
 }
 
 static void
@@ -366,14 +416,14 @@ gv_player_set_pipeline_string(GvPlayer *self, const gchar *pipeline_string)
  * Property accessors - player properties
  */
 
-GvPlayerState
-gv_player_get_state(GvPlayer *self)
+GvPlaybackState
+gv_player_get_playback_state(GvPlayer *self)
 {
 	return self->priv->state;
 }
 
 static void
-gv_player_set_state(GvPlayer *self, GvPlayerState state)
+gv_player_set_playback_state(GvPlayer *self, GvPlaybackState state)
 {
 	GvPlayerPrivate *priv = self->priv;
 
@@ -381,7 +431,7 @@ gv_player_set_state(GvPlayer *self, GvPlayerState state)
 		return;
 
 	priv->state = state;
-	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STATE]);
+	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_PLAYBACK_STATE]);
 }
 
 gboolean
@@ -450,7 +500,7 @@ gv_player_get_prev_station(GvPlayer *self)
 	GvPlayerPrivate *priv = self->priv;
 
 	return gv_station_list_prev(priv->station_list, priv->station,
-	                            priv->repeat, priv->shuffle);
+				    priv->repeat, priv->shuffle);
 }
 
 GvStation *
@@ -459,7 +509,7 @@ gv_player_get_next_station(GvPlayer *self)
 	GvPlayerPrivate *priv = self->priv;
 
 	return gv_station_list_next(priv->station_list, priv->station,
-	                            priv->repeat, priv->shuffle);
+				    priv->repeat, priv->shuffle);
 }
 
 static const gchar *
@@ -551,10 +601,10 @@ gv_player_set_station_by_guessing(GvPlayer *self, const gchar *string)
 }
 
 static void
-gv_player_get_property(GObject    *object,
-                       guint       property_id,
-                       GValue     *value,
-                       GParamSpec *pspec)
+gv_player_get_property(GObject *object,
+		       guint property_id,
+		       GValue *value,
+		       GParamSpec *pspec)
 {
 	GvPlayer *self = GV_PLAYER(object);
 
@@ -579,8 +629,8 @@ gv_player_get_property(GObject    *object,
 	case PROP_PIPELINE_STRING:
 		g_value_set_string(value, gv_player_get_pipeline_string(self));
 		break;
-	case PROP_STATE:
-		g_value_set_enum(value, gv_player_get_state(self));
+	case PROP_PLAYBACK_STATE:
+		g_value_set_enum(value, gv_player_get_playback_state(self));
 		break;
 	case PROP_REPEAT:
 		g_value_set_boolean(value, gv_player_get_repeat(self));
@@ -610,10 +660,10 @@ gv_player_get_property(GObject    *object,
 }
 
 static void
-gv_player_set_property(GObject      *object,
-                       guint         property_id,
-                       const GValue *value,
-                       GParamSpec   *pspec)
+gv_player_set_property(GObject *object,
+		       guint property_id,
+		       const GValue *value,
+		       GParamSpec *pspec)
 {
 	GvPlayer *self = GV_PLAYER(object);
 
@@ -817,17 +867,17 @@ gv_player_go(GvPlayer *self, const gchar *string_to_play)
 	/* That looks like an invalid string then */
 	WARNING("'%s' is neither a known station or a valid URI", string_to_play);
 	gv_errorable_emit_error(GV_ERRORABLE(self),
-	                        _("'%s' is neither a known station or a valid URI"),
-	                        string_to_play);
+				_("'%s' is neither a known station or a valid URI"),
+				string_to_play);
 }
 
 GvPlayer *
 gv_player_new(GvEngine *engine, GvStationList *station_list)
 {
 	return g_object_new(GV_TYPE_PLAYER,
-	                    "engine", engine,
-	                    "station-list", station_list,
-	                    NULL);
+			    "engine", engine,
+			    "station-list", station_list,
+			    NULL);
 }
 
 /*
@@ -843,21 +893,21 @@ gv_player_configure(GvConfigurable *configurable)
 
 	g_assert(gv_core_settings);
 	g_settings_bind(gv_core_settings, "pipeline-enabled",
-	                self, "pipeline-enabled", G_SETTINGS_BIND_DEFAULT);
+			self, "pipeline-enabled", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "pipeline-string",
-	                self, "pipeline-string", G_SETTINGS_BIND_DEFAULT);
+			self, "pipeline-string", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "volume",
-	                self, "volume", G_SETTINGS_BIND_DEFAULT);
+			self, "volume", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "mute",
-	                self, "mute", G_SETTINGS_BIND_DEFAULT);
+			self, "mute", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "repeat",
-	                self, "repeat", G_SETTINGS_BIND_DEFAULT);
+			self, "repeat", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "shuffle",
-	                self, "shuffle", G_SETTINGS_BIND_DEFAULT);
+			self, "shuffle", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "autoplay",
-	                self, "autoplay", G_SETTINGS_BIND_DEFAULT);
+			self, "autoplay", G_SETTINGS_BIND_DEFAULT);
 	g_settings_bind(gv_core_settings, "station-uri",
-	                self, "station-uri", G_SETTINGS_BIND_DEFAULT);
+			self, "station-uri", G_SETTINGS_BIND_DEFAULT);
 }
 
 static void
@@ -905,10 +955,10 @@ gv_player_constructed(GObject *object)
 	g_assert_nonnull(priv->station_list);
 
 	/* Initialize properties */
-	priv->repeat   = DEFAULT_REPEAT;
-	priv->shuffle  = DEFAULT_SHUFFLE;
+	priv->repeat = DEFAULT_REPEAT;
+	priv->shuffle = DEFAULT_SHUFFLE;
 	priv->autoplay = DEFAULT_AUTOPLAY;
-	priv->station  = NULL;
+	priv->station = NULL;
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_player, object);
@@ -940,88 +990,94 @@ gv_player_class_init(GvPlayerClass *class)
 
 	/* Construct-only properties */
 	properties[PROP_ENGINE] =
-	        g_param_spec_object("engine", "Engine", NULL,
-	                            GV_TYPE_ENGINE,
-	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
+		g_param_spec_object("engine", "Engine", NULL,
+				    GV_TYPE_ENGINE,
+				    GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_STATION_LIST] =
-	        g_param_spec_object("station-list", "Station list", NULL,
-	                            GV_TYPE_STATION_LIST,
-	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
+		g_param_spec_object("station-list", "Station list", NULL,
+				    GV_TYPE_STATION_LIST,
+				    GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	/* Engine mirrored properties */
 	properties[PROP_STREAMINFO] =
-	        g_param_spec_boxed("streaminfo", "Stream information", NULL,
-	                           GV_TYPE_STREAMINFO,
-	                           GV_PARAM_READABLE);
+		g_param_spec_boxed("streaminfo", "Stream information", NULL,
+				   GV_TYPE_STREAMINFO,
+				   GV_PARAM_READABLE);
 
 	properties[PROP_METADATA] =
-	        g_param_spec_boxed("metadata", "Current metadata", NULL,
-	                           GV_TYPE_METADATA,
-	                           GV_PARAM_READABLE);
+		g_param_spec_boxed("metadata", "Current metadata", NULL,
+				   GV_TYPE_METADATA,
+				   GV_PARAM_READABLE);
 
 	properties[PROP_VOLUME] =
-	        g_param_spec_uint("volume", "Volume in percent", NULL,
-	                          0, 100, DEFAULT_VOLUME,
-	                          GV_PARAM_READWRITE);
+		g_param_spec_uint("volume", "Volume in percent", NULL,
+				  0, 100, DEFAULT_VOLUME,
+				  GV_PARAM_READWRITE);
 
 	properties[PROP_MUTE] =
-	        g_param_spec_boolean("mute", "Mute", NULL,
-	                             DEFAULT_MUTE,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("mute", "Mute", NULL,
+				     DEFAULT_MUTE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_ENABLED] =
-	        g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
-	                             FALSE,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
+				     FALSE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_STRING] =
-	        g_param_spec_string("pipeline-string", "Custom pipeline string", NULL,
-	                            NULL,
-	                            GV_PARAM_READWRITE);
+		g_param_spec_string("pipeline-string", "Custom pipeline string", NULL,
+				    NULL,
+				    GV_PARAM_READWRITE);
 
 	/* Player properties */
-	properties[PROP_STATE] =
-	        g_param_spec_enum("state", "Playback state", NULL,
-	                          GV_TYPE_PLAYER_STATE,
-	                          GV_PLAYER_STATE_STOPPED,
-	                          GV_PARAM_READABLE);
+	properties[PROP_PLAYBACK_STATE] =
+		g_param_spec_enum("playback-state", "Playback state", NULL,
+				  GV_TYPE_PLAYBACK_STATE,
+				  GV_PLAYBACK_STATE_STOPPED,
+				  GV_PARAM_READABLE);
 
 	properties[PROP_REPEAT] =
-	        g_param_spec_boolean("repeat", "Repeat", NULL,
-	                             DEFAULT_REPEAT,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("repeat", "Repeat", NULL,
+				     DEFAULT_REPEAT,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_SHUFFLE] =
-	        g_param_spec_boolean("shuffle", "Shuffle", NULL,
-	                             DEFAULT_SHUFFLE,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("shuffle", "Shuffle", NULL,
+				     DEFAULT_SHUFFLE,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_AUTOPLAY] =
-	        g_param_spec_boolean("autoplay", "Autoplay on startup", NULL,
-	                             DEFAULT_AUTOPLAY,
-	                             GV_PARAM_READWRITE);
+		g_param_spec_boolean("autoplay", "Autoplay on startup", NULL,
+				     DEFAULT_AUTOPLAY,
+				     GV_PARAM_READWRITE);
 
 	properties[PROP_STATION] =
-	        g_param_spec_object("station", "Current station", NULL,
-	                            GV_TYPE_STATION,
-	                            GV_PARAM_READWRITE);
+		g_param_spec_object("station", "Current station", NULL,
+				    GV_TYPE_STATION,
+				    GV_PARAM_READWRITE);
 
 	properties[PROP_STATION_URI] =
-	        g_param_spec_string("station-uri", "Current station URI",
-	                            "This is used only to save the current station in conf",
-	                            NULL,
-	                            GV_PARAM_READWRITE);
+		g_param_spec_string("station-uri", "Current station URI",
+				    "This is used only to save the current station in conf",
+				    NULL,
+				    GV_PARAM_READWRITE);
 
 	properties[PROP_PREV_STATION] =
-	        g_param_spec_object("prev", "Previous station", NULL,
-	                            GV_TYPE_STATION,
-	                            GV_PARAM_READABLE);
+		g_param_spec_object("prev", "Previous station", NULL,
+				    GV_TYPE_STATION,
+				    GV_PARAM_READABLE);
 
 	properties[PROP_NEXT_STATION] =
-	        g_param_spec_object("next", "Next station", NULL,
-	                            GV_TYPE_STATION,
-	                            GV_PARAM_READABLE);
+		g_param_spec_object("next", "Next station", NULL,
+				    GV_TYPE_STATION,
+				    GV_PARAM_READABLE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
+
+	/* Signals */
+	signals[SIGNAL_SSL_FAILURE] =
+		g_signal_new("ssl-failure", G_TYPE_FROM_CLASS(class),
+			     G_SIGNAL_RUN_LAST, 0, NULL, NULL, NULL,
+			     G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 }
