@@ -28,6 +28,7 @@
 #include "ui/gtk-additions.h"
 #include "ui/gv-stations-tree-view.h"
 #include "ui/gv-ui-internal.h"
+#include "ui/gv-volume-control.h"
 
 #include "ui/gv-playlist-view.h"
 
@@ -63,12 +64,13 @@ struct _GvPlaylistViewPrivate {
 	GtkWidget *playback_status_label;
 	GtkWidget *go_next_button;
 	/* Controls */
+	GtkWidget *button_box;
 	GtkWidget *play_button;
 	GtkWidget *prev_button;
 	GtkWidget *next_button;
+	GtkWidget *volume_control;
 	GtkWidget *repeat_toggle_button;
 	GtkWidget *shuffle_toggle_button;
-	GtkWidget *volume_button;
 	/* Station list */
 	GtkWidget *scrolled_window;
 	GtkWidget *stations_tree_view;
@@ -79,7 +81,6 @@ struct _GvPlaylistViewPrivate {
 
 	GBinding *repeat_binding;
 	GBinding *shuffle_binding;
-	GBinding *volume_binding;
 };
 
 typedef struct _GvPlaylistViewPrivate GvPlaylistViewPrivate;
@@ -162,17 +163,6 @@ set_play_button(GtkButton *button, GvPlaybackState state)
 	gtk_button_set_image(button, image);
 }
 
-static void
-set_volume_button(GtkVolumeButton *volume_button, guint volume, gboolean mute)
-{
-	GtkScaleButton *scale_button = GTK_SCALE_BUTTON(volume_button);
-
-	if (mute)
-		gtk_scale_button_set_value(scale_button, 0);
-	else
-		gtk_scale_button_set_value(scale_button, volume);
-}
-
 /*
  * Private methods
  */
@@ -208,21 +198,6 @@ gv_playlist_view_update_play_button(GvPlaylistView *self, GvPlayer *player)
 	set_play_button(button, state);
 }
 
-static void
-gv_playlist_view_update_volume_button(GvPlaylistView *self, GvPlayer *player)
-{
-	GvPlaylistViewPrivate *priv = self->priv;
-	GtkVolumeButton *volume_button = GTK_VOLUME_BUTTON(priv->volume_button);
-	guint volume = gv_player_get_volume(player);
-	gboolean mute = gv_player_get_mute(player);
-
-	g_binding_unbind(priv->volume_binding);
-	set_volume_button(volume_button, volume, mute);
-	priv->volume_binding = g_object_bind_property(
-		player, "volume", volume_button, "value",
-		G_BINDING_BIDIRECTIONAL);
-}
-
 /*
  * Signal handlers
  */
@@ -243,8 +218,6 @@ on_player_notify(GvPlayer *player,
 		gv_playlist_view_update_play_button(self, player);
 	} else if (!g_strcmp0(property_name, "metadata")) {
 		gv_playlist_view_update_playback_status_label(self, player);
-	} else if (!g_strcmp0(property_name, "mute")) {
-		gv_playlist_view_update_volume_button(self, player);
 	}
 }
 
@@ -290,14 +263,10 @@ on_map(GvPlaylistView *self, gpointer user_data)
 	priv->shuffle_binding = g_object_bind_property(
 		player, "shuffle", priv->shuffle_toggle_button, "active",
 		G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-	priv->volume_binding = g_object_bind_property(
-		player, "volume", priv->volume_button, "value",
-		G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
 
 	gv_playlist_view_update_station_name_label(self, player);
 	gv_playlist_view_update_playback_status_label(self, player);
 	gv_playlist_view_update_play_button(self, player);
-	gv_playlist_view_update_volume_button(self, player);
 }
 
 static void
@@ -314,8 +283,6 @@ on_unmap(GvPlaylistView *self, gpointer user_data G_GNUC_UNUSED)
 	priv->repeat_binding = NULL;
 	g_binding_unbind(priv->shuffle_binding);
 	priv->shuffle_binding = NULL;
-	g_binding_unbind(priv->volume_binding);
-	priv->volume_binding = NULL;
 }
 
 /*
@@ -332,23 +299,6 @@ gv_playlist_view_new(void)
  * Construct helpers
  */
 
-static void
-setup_adjustment(GtkScaleButton *scale_button, GObject *obj, const gchar *obj_prop)
-{
-	GtkAdjustment *adjustment;
-	guint minimum, maximum;
-	guint range;
-
-	g_object_get_property_uint_bounds(obj, obj_prop, &minimum, &maximum);
-	range = maximum - minimum;
-
-	adjustment = gtk_scale_button_get_adjustment(scale_button);
-	gtk_adjustment_set_lower(adjustment, minimum);
-	gtk_adjustment_set_upper(adjustment, maximum);
-	gtk_adjustment_set_step_increment(adjustment, range / 100);
-	gtk_adjustment_set_page_increment(adjustment, range / 10);
-}
-
 static void
 gv_playlist_view_populate_widgets(GvPlaylistView *self)
 {
@@ -370,12 +320,16 @@ gv_playlist_view_populate_widgets(GvPlaylistView *self)
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, go_next_button);
 
 	/* Button box */
+	GTK_BUILDER_SAVE_WIDGET(builder, priv, button_box);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, play_button);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, prev_button);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, next_button);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, repeat_toggle_button);
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, shuffle_toggle_button);
-	GTK_BUILDER_SAVE_WIDGET(builder, priv, volume_button);
+
+	/* Create the volume control, add it to the button box */
+	priv->volume_control = gv_volume_control_new();
+	gtk_container_add(GTK_CONTAINER(priv->button_box), priv->volume_control);
 
 	/* Stations tree view */
 	GTK_BUILDER_SAVE_WIDGET(builder, priv, scrolled_window);
@@ -410,16 +364,12 @@ static void
 gv_playlist_view_setup_widgets(GvPlaylistView *self)
 {
 	GvPlaylistViewPrivate *priv = self->priv;
-	GObject *player_obj = G_OBJECT(gv_core_player);
 
 	/* Give a name to some widgets, for the status icon window */
 	gtk_widget_set_name(priv->go_next_button, "go_next_button");
 	gtk_widget_set_name(priv->station_name_label, "station_name_label");
 	gtk_widget_set_name(priv->stations_tree_view, "stations_tree_view");
 
-	/* Setup adjustment for the volume button */
-	setup_adjustment(GTK_SCALE_BUTTON(priv->volume_button), player_obj, "volume");
-
 	/* Connect next button */
 	g_signal_connect_object(priv->go_next_button, "clicked",
 				G_CALLBACK(on_go_next_button_clicked), self, 0);
